@@ -106,6 +106,7 @@
 
 (define-class <intr-property> (<intr-entity>)
   (s-class-name #:init-keyword #:s-class-name)
+  (s-property-class #:init-keyword #:s-property-class)
   (has-getter? #:init-keyword #:has-getter?)
   (has-setter? #:init-keyword #:has-setter?)
   (s-getter-name #:init-keyword #:s-getter-name)
@@ -684,6 +685,8 @@
     (do ((i 0 (+ i 1))) ((>= i i-count))
       (let* ((info-prop (g-object-info-get-property info i))
 	     (str-prop-name (g-base-info-get-name info-prop))
+	     (prop-type (g-property-info-get-type info-prop))
+	     (s-property-class (get-target-type2 prop-type))
 	     (str-accessor-name (string-append "!" str-prop-name))
 	     (s-accessor-name (string->symbol str-accessor-name))
 	     (l-prop-flags (g-property-info-get-flags info-prop))
@@ -709,11 +712,15 @@
 		#:str-name str-prop-name
 		#:s-target-name '()
 		#:s-class-name s-class-name
+		#:s-property-class s-property-class
 		#:has-getter? def-getter?
 		#:has-setter? def-setter?
 		#:s-getter-name s-getter-name
 		#:s-setter-name s-setter-name
 		#:s-accessor-name s-accessor-name)))
+	(if (eq? (g-type-info-get-tag prop-type) 'interface)
+	    (gi-import-info1 (g-type-info-get-interface prop-type)
+			     generator #f #f))
 	(add-entity generator intr-property)
 	(set! l-properties (cons intr-property l-properties))))
     (slot-set! intr-object 'l-properties l-properties)))
@@ -806,6 +813,35 @@
 	(list ':alt-maybe x))))
 
 
+(define (get-target-type2 prop-type)
+  (let ((s-tag (g-type-info-get-tag prop-type)))
+    (case s-tag
+      ((interface)
+       (let* ((intf (g-type-info-get-interface prop-type))
+	      (s-result
+	       (g-name->class-name (gi-registered-type-info-name intf))))
+	 s-result))
+      ((void)
+       (raise 'void-property-type))
+      ((boolean)
+       '<boolean>)
+      ((int64 uint64 int32 uint32 int16 uint16 int8 uint8)
+       '<integer>)
+      ((double float)
+       '<real>)
+      ((utf8 filename)
+       '<string>)
+      ((unichar)
+       '<character>)
+      ((glist gslist) '<list>)
+      ((array)
+       '<object>)
+      ((gtype)
+       '<symbol>)
+      (else
+       (raise (list 'unknown-type-tag (cons 'tag s-tag)))))))
+
+
 (define (get-argument-type x-arg)
   (let ((tag (!type-tag x-arg))
 	(type-desc (!type-desc x-arg))
